aboutsummaryrefslogtreecommitdiff
path: root/app/class/Medialist.php
diff options
context:
space:
mode:
Diffstat (limited to 'app/class/Medialist.php')
-rw-r--r--app/class/Medialist.php18
1 files changed, 9 insertions, 9 deletions
diff --git a/app/class/Medialist.php b/app/class/Medialist.php
index 3395b58..b0964e3 100644
--- a/app/class/Medialist.php
+++ b/app/class/Medialist.php
@@ -7,8 +7,8 @@ class Medialist extends Item
/** @var string full regex match */
protected $fullmatch;
- /** @var string full filter code line */
- protected $filter = '';
+ /** @var string full options code line */
+ protected $options = '';
/** @var string directory of media */
protected $path = '';
@@ -45,9 +45,9 @@ class Medialist extends Item
$this->hydrate($datas);
}
- public function readfilter()
+ public function readoptions()
{
- parse_str($this->filter, $datas);
+ parse_str($this->options, $datas);
$this->hydrate($datas);
}
@@ -137,9 +137,9 @@ class Medialist extends Item
return $this->fullmatch;
}
- public function filter()
+ public function options()
{
- return $this->filter;
+ return $this->options;
}
/**
@@ -182,10 +182,10 @@ class Medialist extends Item
}
- public function setfilter(string $filter)
+ public function setoptions(string $options)
{
- if (!empty($filter)) {
- $this->filter = $filter;
+ if (!empty($options)) {
+ $this->options = $options;
}
}